from natch.hashers.qualname_hasher import QualnameHasher


__all__ = [
    'QualnameHasher',
]
